@@ -327,7 +327,7 @@ def ezfindwidth(x, y, halfwidth = False, height = 0.5, interp_points = 1e6, pos
     if halfwidth is True:
         width /= 2
         
-        return width
+    return width
 
 
 
@@ -702,11 +702,11 @@ class Pulse:
             - FWHM: float
         """
         v, s = ezfft(self.t, self.E)
-        if domain is "time":
+        if domain == "time":
             return ezfindwidth(self.t, np.abs(self.E)**2)
-        elif domain is "frequency":
+        elif domain == "frequency":
             return ezfindwidth(v, np.abs(s)**2)
-        elif domain is "wavelength":
+        elif domain == "wavelength":
             l = C/v
             return ezfindwidth(l, np.abs(s)**2)
         else:
